Rev 1.6 - Sample Period Work in progress

Dependencies:   mbed Bitmap N5110 TMP102 Joystick

Revision:
1:5cdfc8d78097
Parent:
0:f8a8c6a8a5c3
Child:
2:94cc00f20883
diff -r f8a8c6a8a5c3 -r 5cdfc8d78097 main.cpp
--- a/main.cpp	Sat Dec 04 13:19:24 2021 +0000
+++ b/main.cpp	Sat Dec 04 16:44:21 2021 +0000
@@ -1,74 +1,73 @@
-/* 
-
-2645_I2C_TMP102_Library
-
-Sample code from ELEC2645 Week 17 Lab
-
-Demonstrates how to re-factor the TMP102 code into a library
-
-(c) Craig A. Evans, University of Leeds, Feb 2016
+/*
+@Acknowledgements to Craig A.Evans for TMP102 Library reading temperatures
 
 */ 
+/*============================ Libraries =====================================*/
+#include "mbed.h"                                                               // Including Mbed OS Header File Libraries
+#include "TMP102.h"                                                             // Including Tmp102 Header File Libraries
 
-#include "mbed.h"
-// include the library header, ensure the library has been imported into the project
-#include "TMP102.h"
 
-// Create TMP102 object
-TMP102 Tmp_I2C(I2C_SDA,I2C_SCL);  
-// UART connection for PC
-Serial pc(USBTX,USBRX);
+/*============================ Variables =====================================*/
+//Serial
+TMP102 Tmp_I2C(PTE25,PTE24);                                                    //Establishing TMP102 I2C Sensor (I2C_SDA(PTE25),I2C_SCL(PTE24)
+Serial serial(USBTX,USBRX);                                                     //Serial Port 
 
-// K64F on-board LEDs 
-DigitalOut Red_DO(LED_RED);
+//Outputs                                                                                
+DigitalOut Red_DO(LED_RED);                                                     // K64F on-board LEDs 
 DigitalOut Grn_DO(LED_GREEN);
 DigitalOut Blue_DO(LED_BLUE);
-// K64F on-board switches
-InterruptIn Sw2_DI(SW2);
+//Inputs
+InterruptIn Sw2_DI(SW2);                                                        // K64F on-board switches
 InterruptIn Sw3_DI(SW3);
 
-// error function hangs flashing an LED
-void error();
-// setup serial port
-void init_serial();
-// set-up the on-board LEDs and switches
-void init_K64F();
+/*=========================== Void Functions =================================*/
+
+void error();                                                                   // error function flashing blue LED from TMP102.cpp and prints Error State to CoolTerm
 
+void init_serial();                                                             // Serial port setup
+
+void init_K64FSetup();                                                          // Disabling on-board LEDs and switches
+
+/*============================ Main Code =====================================*/
 int main()
 {
-    // initialise the board and serial port
-    init_K64F();
+    serial.baud(9600);
+
+    init_K64FSetup();                                                           // Initiliasing the Void Functions into the main code
     init_serial(); 
-    // call the sensor init method using dot syntax
-    Tmp_I2C.init();
+    error();
+    
+    Tmp_I2C.init();                                                             // I2C Sensor Initialising
     
     while (1) {
         
-        // read temperature and print over serial port
-        float T = Tmp_I2C.get_temperature();
-        pc.printf("T = %f K\n",T);
-        // small delay - 1s to match the update rate of the sensor (1 Hz)
-        wait(1.0);
+        float T = Tmp_I2C.get_temperature();                                    // Read Temp from I2C Sensor
+        serial.printf("T = %f C\n",T);                                          // Print Value over CoolTerm
+        
+        wait(1.0);                                                              // small delay - 1s to match the update rate of the sensor (1 Hz)
         
     }
+}
 
-}
+/*=============================== Void Setup =================================*/
 
 void init_serial() {
     // set to highest baud - ensure terminal software matches
-    pc.baud(115200); 
+    serial.baud(9600); 
 }
 
-void init_K64F() 
+void init_K64FSetup() 
 {
-    // on-board LEDs are active-low, so set pin high to turn them off.
-    Red_DO = 1;
+                                                                                
+    Red_DO = 1;                                                                 // on-board LEDs are active-low, so set pin high to turn them off.
     Grn_DO = 1;
     Blue_DO = 1;   
-    
-    // since the on-board switches have external pull-ups, we should disable the internal pull-down
-    // resistors that are enabled by default using InterruptIn
-    Sw2_DI.mode(PullNone);
-    Sw3_DI.mode(PullNone);
+                                                                                                                                                                    
+    Sw2_DI.mode(PullNone);                                                      // since the on-board switches have external pull-ups, we should disable the internal pull-down
+    Sw3_DI.mode(PullNone);                                                      // resistors that are enabled by default using InterruptIn
 
 }
+void error(){
+    serial.baud(9600);                                                          // Serial Baud Rate
+    serial.printf("Error State");                                               // Error Print Message
+}